@@ -4,7 +4,7 @@
 """
 from __future__ import absolute_import
 
-from .base import Nut, NutSink, NutSource, NutFunction
+from nutsflow.base import Nut, NutSink, NutSource, NutFunction
 
 
 def _arg_insert(args, arg, pos=0):
@@ -45,6 +45,7 @@ def _create_nut_wrapper(base_class, func, iterpos):
 
     Wrapper.__name__ = func.__name__
     Wrapper.__module__ = func.__module__
+    #Wrapper.__rrshift__.__doc__ = ""   # Py 2.7 doesn't permit this
     return Wrapper
 
 
@@ -67,6 +68,79 @@ def _create_filter_wrapper(func, invert=False):
                 if bool(func(*args, **self.kwargs)) != invert:
                     yield e
 
+    Wrapper.__name__ = func.__name__
+    Wrapper.__module__ = func.__module__
+    #Wrapper.__rrshift__.__doc__ = ""  # Py 2.7 doesn't permit this
+    return Wrapper
+
+
+def nut_function(func):
+    """
+    Decorator for Nut functions.
+
+    Example on how to define a custom function nut:
+
+    .. code::
+
+      @nut_function
+      def TimesN(x, n):
+          return x * n
+
+      [1, 2, 3] >> TimesN(2) >> Collect()  -->  [2, 4, 6]
+
+    :param function func: Function to decorate
+    :return: Nut function for given function
+    :rtype: NutFunction
+    """
+
+    class Wrapper(NutFunction):
+        __doc__ = func.__doc__
+
+        def __call__(self, element):
+            return func(element, *self.args, **self.kwargs)
+
+    Wrapper.__name__ = func.__name__
+    Wrapper.__module__ = func.__module__
+    #Wrapper.__call__.__doc__ = ""  # Py 2.7 doesn't permit this
+    return Wrapper
+
+
+def nut_source(func):
+    """
+    Decorator for Nut sources.
+
+    Example on how to define a custom source nut. Note that a source
+    must return an iterable/generator and does not read any input.
+
+    .. code::
+
+      @nut_source
+      def MyRange(start, end):
+          return range(start, end)
+
+      MyRange(0, 5) >> Collect()  --> [0, 1, 2, 3, 4]
+
+
+    .. code::
+
+      @nut_source
+      def MyRange2(start, end):
+          for i in range(start, end):
+              yield i * 2
+
+      MyRange2(0, 5) >> Collect()  --> [0, 2, 4, 6, 8]
+
+    :param function func: Function to decorate
+    :return: Nut source for given function
+    :rtype: NutSource
+    """
+
+    class Wrapper(NutSource):
+        __doc__ = func.__doc__
+
+        def __iter__(self):
+            return func(*self.args, **self.kwargs)
+
     Wrapper.__name__ = func.__name__
     Wrapper.__module__ = func.__module__
     return Wrapper
@@ -162,77 +236,6 @@ def nut_sink(func, iterpos=0):
     return _create_nut_wrapper(NutSink, func, iterpos)
 
 
-def nut_function(func):
-    """
-    Decorator for Nut functions.
-
-    Example on how to define a custom function nut:
-
-    .. code::
-
-      @nut_function
-      def TimesN(x, n):
-          return x * n
-
-      [1, 2, 3] >> TimesN(2) >> Collect()  -->  [2, 4, 6]
-
-    :param function func: Function to decorate
-    :return: Nut function for given function
-    :rtype: NutFunction
-    """
-
-    class Wrapper(NutFunction):
-        __doc__ = func.__doc__
-
-        def __call__(self, element):
-            return func(element, *self.args, **self.kwargs)
-
-    Wrapper.__name__ = func.__name__
-    Wrapper.__module__ = func.__module__
-    return Wrapper
-
-
-def nut_source(func):
-    """
-    Decorator for Nut sources.
-
-    Example on how to define a custom source nut. Note that a source
-    must return an iterable/generator and does not read any input.
-
-    .. code::
-
-      @nut_source
-      def MyRange(start, end):
-          return range(start, end)
-
-      MyRange(0, 5) >> Collect()  --> [0, 1, 2, 3, 4]
-
-
-    .. code::
-
-      @nut_source
-      def MyRange2(start, end):
-          for i in range(start, end):
-              yield i * 2
-
-      MyRange2(0, 5) >> Collect()  --> [0, 2, 4, 6, 8]
-
-    :param function func: Function to decorate
-    :return: Nut source for given function
-    :rtype: NutSource
-    """
-
-    class Wrapper(NutSource):
-        __doc__ = func.__doc__
-
-        def __iter__(self):
-            return func(*self.args, **self.kwargs)
-
-    Wrapper.__name__ = func.__name__
-    Wrapper.__module__ = func.__module__
-    return Wrapper
-
-
 def nut_filter(func):
     """
     Decorator for Nut filters.
